@@ -1,6 +1,8 @@
 from bn.bn import tokenizer
 from bn.bn import remove_punctuation
 from bn.bn import remove_foreign
+from bn.bn import remove_numbers
+from bn.bn import remove_stopwords
 from bn.bn import find_numbers
 from bn.bn import ban_to_eng_num
 from bn.bn import eng_to_ban_num
